<?php
/**
 * ameen Theme Customizer
 *
 * @package ameen
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ameen_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage'; 
   

      $wp_customize->add_setting('blogpage_title', array(
          'default' => 'Blog Page',
          'transport' => 'postMessage',
          'sanitize_callback' => 'wp_filter_nohtml_kses' //removes all HTML from content
      ));
      
      $wp_customize->add_control('blogpage_title', array(
         'label' => esc_html__('Blog Page Title', 'ameen'),
          'section' => 'title_tagline',
          'settings' => 'blogpage_title',
          'type' => 'text',
      ));
      $wp_customize->add_setting('ameen_footer_text', array(
          'default' => 'Copyright Text',
          'transport' => 'postMessage',
          'sanitize_callback' => 'wp_kses_stripslashes' 
      ));
      
      $wp_customize->add_control('ameen_footer_text', array(
         'label' => esc_html__( 'Footer Text', 'ameen' ),
          'section' => 'title_tagline',
          'settings' => 'ameen_footer_text',
          'type' => 'text',
      ));
      $wp_customize->add_setting('ameen_social_fb', array(
          'default' => 'https://www.facebook.com',
          'transport' => 'postMessage',
          'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
      ));
      $wp_customize->add_control('ameen_social_fb', array(
         'label' => esc_html__( 'Footer Fb Link', 'ameen' ),
          'section' => 'title_tagline',
          'settings' => 'ameen_social_fb',
          'type' => 'url',
      ));
      $wp_customize->add_setting('ameen_social_twitter', array(
          'default' => 'https://www.twitter.com',
          'transport' => 'postMessage',
          'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
      ));
      $wp_customize->add_control('ameen_social_twitter', array(
         'label' => esc_html__('Footer Twitter Link', 'ameen'),
          'section' => 'title_tagline',
          'settings' => 'ameen_social_twitter',
          'type' => 'url',
      ));
      $wp_customize->add_setting('ameen_social_gplus', array(
          'default' => 'https://plus.google.com',
          'transport' => 'postMessage',
          'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
      ));
      $wp_customize->add_control('ameen_social_gplus', array(
         'label' => esc_html__('Footer Gplus Link', 'ameen'),
          'section' => 'title_tagline',
          'settings' => 'ameen_social_gplus',
          'type' => 'url',
      ));
      $wp_customize->add_setting('ameen_social_instagram', array(
          'default' => 'https://www.instagram.com',
          'transport' => 'postMessage',
          'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
      ));
      $wp_customize->add_control('ameen_social_instagram', array(
         'label' => esc_html__('Footer Instagram Link', 'ameen'),
          'section' => 'title_tagline',
          'settings' => 'ameen_social_instagram',
          'type' => 'url',
      ));
      $wp_customize->add_setting('ameen_social_pinterest', array(
          'default' => 'https://www.pinterest.com',
          'transport' => 'postMessage',
          'sanitize_callback' => 'esc_url_raw' //cleans URL from all invalid characters
      ));
      $wp_customize->add_control('ameen_social_pinterest', array(
         'label' => esc_html__('Footer Pinterest Link', 'ameen'),
          'section' => 'title_tagline',
          'settings' => 'ameen_social_pinterest',
          'type' => 'url',
      ));
      
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'ameen_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'ameen_customize_partial_blogdescription',
		) );
                $wp_customize->selective_refresh->add_partial( 'ameen_footer_text', array(
			'selector'        => '.site-info',
			'render_callback' => 'ameen_customize_partial_footer_text',
		) );
	}
}
add_action( 'customize_register', 'ameen_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ameen_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ameen_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ameen_customize_preview_js() {
	wp_enqueue_script( 'ameen-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'ameen_customize_preview_js' );
